Version 2.x — Invenio 3.1.2 documentation

# Version 2.x

End-of-life

Invenio v2.x code base is a hybrid architecture that uses Flask web development framework combined with Invenio v1.x framework.

Note

The 2.x code base is not suitable for production systems, and will not receive any further development nor security fixes.

Released versions include:

Invenio v2.1:

- v2.1.1 - released 2015-09-01

- v2.1.0 - released 2015-06-16

Invenio v2.0:

- v2.0.6 - released 2015-09-01

- v2.0.5 - released 2015-07-17

- v2.0.4 - released 2015-06-01

- v2.0.3 - released 2015-05-15

- v2.0.2 - released 2015-04-17

- v2.0.1 - released 2015-03-20

- v2.0.0 - released 2015-03-04